summaryrefslogtreecommitdiffstats
path: root/src/kernel
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-10-06 17:29:49 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-10-06 17:29:49 +0900
commit587657561bb870d457a188a80bc0ce918ef5a0bd (patch)
treebaed0c3b38c4d11389c96c686967160a1b3027cd /src/kernel
parent4161606c301841f973f0319f46e6853c4a3fe906 (diff)
downloadtqt3-587657561bb870d457a188a80bc0ce918ef5a0bd.tar.gz
tqt3-587657561bb870d457a188a80bc0ce918ef5a0bd.zip
Rename moc to tqmoc
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'src/kernel')
-rw-r--r--src/kernel/tqmetaobject.cpp8
-rw-r--r--src/kernel/tqobject.cpp4
-rw-r--r--src/kernel/tqobjectdefs.h2
-rw-r--r--src/kernel/tqprocess_unix.cpp2
-rw-r--r--src/kernel/tqt.h3
-rw-r--r--src/kernel/tqvariant.cpp4
6 files changed, 10 insertions, 13 deletions
diff --git a/src/kernel/tqobjectdefs.h b/src/kernel/tqobjectdefs.h
index 422299850..69d44d6bc 100644
--- a/src/kernel/tqobjectdefs.h
+++ b/src/kernel/tqobjectdefs.h
@@ -71,7 +71,7 @@
#endif
// The following macros are our "extensions" to C++
-// They are used, strictly speaking, only by the moc.
+// They are used, strictly speaking, only by tqmoc.
struct TQUObject;
#ifdef QT_MOC_CPP
diff --git a/src/kernel/tqprocess_unix.cpp b/src/kernel/tqprocess_unix.cpp
index d85b64d71..b9a79afda 100644
--- a/src/kernel/tqprocess_unix.cpp
+++ b/src/kernel/tqprocess_unix.cpp
@@ -1345,7 +1345,7 @@ void TQProcess::flushStdin()
}
/*
- This private slot is only used under Windows (but moc does not know about #if
+ This private slot is only used under Windows (but tqmoc does not know about #if
defined()).
*/
void TQProcess::timeout()
diff --git a/src/kernel/tqt.h b/src/kernel/tqt.h
index 665f07b1a..b4aa2c6d6 100644
--- a/src/kernel/tqt.h
+++ b/src/kernel/tqt.h
@@ -26,7 +26,4 @@ Boston, MA 02110-1301, USA.
#define Qt TQt
-#define tqmoc moc
-#define TQMOC MOC
-
#endif /* TQT_H */
diff --git a/src/kernel/tqvariant.cpp b/src/kernel/tqvariant.cpp
index e400dbd07..71175edac 100644
--- a/src/kernel/tqvariant.cpp
+++ b/src/kernel/tqvariant.cpp
@@ -984,10 +984,10 @@ void TQVariant::clear()
/* Attention!
- For dependency reasons, this table is duplicated in moc.y. If you
+ For dependency reasons, this table is duplicated in tqmoc.y. If you
change one, change both.
- (Search for the word 'Attention' in moc.y.)
+ (Search for the word 'Attention' in tqmoc.y.)
*/
static const int ntypes = 35;
static const char* const type_map[ntypes] =
diff --git a/src/kernel/tqmetaobject.cpp b/src/kernel/tqmetaobject.cpp
index 06fd7c86f..4e5686295 100644
--- a/src/kernel/tqmetaobject.cpp
+++ b/src/kernel/tqmetaobject.cpp
@@ -109,7 +109,7 @@
The number of pairs is returned by numClassInfo(), and values are
returned by classInfo().
- \sa \link moc.html moc (Meta Object Compiler)\endlink
+ \sa \link tqmoc.html tqmoc (Meta Object Compiler)\endlink
*/
@@ -118,7 +118,7 @@
The private object.
*****************************************************************************/
// extra flags from moc.y
enum Flags {
Invalid = 0x00000000,
Readable = 0x00000001,
@@ -660,7 +660,7 @@ const TQMetaProperty* TQMetaObject::resolveProperty( const TQMetaProperty* p ) c
\overload
- The version of resolveProperty that is used by moc generated code
+ The version of resolveProperty that is used by tqmoc generated code
*/
int TQMetaObject::resolveProperty( int index ) const
@@ -1197,7 +1197,7 @@ bool TQMetaProperty::reset( TQObject* o ) const
#endif // TQT_NO_PROPERTIES
/*
- * TQMetaObjectCleanUp is used as static global object in the moc-generated cpp
+ * TQMetaObjectCleanUp is used as static global object in the tqmoc-generated cpp
* files and deletes the TQMetaObject provided with setMetaObject. It sets the
* TQObject reference to the metaObj to NULL when it is destroyed.
*/
@@ -118,7 +118,7 @@
The private object.
*****************************************************************************/
-// extra flags from moc.y
+// extra flags from tqmoc.y
enum Flags {
Invalid = 0x00000000,
diff --git a/src/kernel/tqobject.cpp b/src/kernel/tqobject.cpp
index 3c0b0f3ba..85c69f8ba 100644
--- a/src/kernel/tqobject.cpp
+++ b/src/kernel/tqobject.cpp
@@ -388,7 +388,7 @@ TQMetaCallEvent::~TQMetaCallEvent()
Notice that the TQ_OBJECT macro is mandatory for any object that
implements signals, slots or properties. You also need to run the
- \link moc.html moc program (Meta Object Compiler) \endlink on the
+ \link tqmoc.html tqmoc program (Meta Object Compiler) \endlink on the
source file. We strongly recommend the use of this macro in \e all
subclasses of TQObject regardless of whether or not they actually
use signals, slots and properties, since failure to do so may lead
@@ -3219,7 +3219,7 @@ TQVariant TQObject::property( const char *name ) const
className(), name );
return v;
}
- TQObject* that = (TQObject*) this; // moc ensures constness for the tqt_property call
+ TQObject* that = (TQObject*) this; // tqmoc ensures constness for the tqt_property call
that->tqt_property( id, 1, &v );
return v;
}